@@ -47,7 +47,10 @@ class JsonApiViewBuilder:
         self._related_limit = self.DEFAULT_RELATED_LIMIT
         self._permission_classes = permission_classes or []
         self._authentication_classes = authentication_classes or []
-        self._queryset = queryset or self._model.objects
+        if queryset is None:
+            self._queryset = self._model.objects
+        else:
+            self._queryset = queryset
         self._skip_plugins = skip_plugins or []
 
     @staticmethod
@@ -118,6 +121,7 @@ class JsonApiViewBuilder:
 
     def _get_history_urls(self) -> Sequence[partial]:
         history_builder = deepcopy(self)
+        history_builder._skip_plugins = [plugins.DJANGO_SIMPLE_HISTORY]
         history_builder._model = apps.get_model(self._model.objects.model._meta.db_table.split('_')[0],
                                                 f'Historical{self._model.__name__}')
         history_builder._queryset = self._model.history
@@ -137,14 +141,22 @@ class JsonApiViewBuilder:
     def _build(self, url_resource_name: str = '', urls_prefix: str = '') -> Sequence[partial]:
         method_to_serializer = {}
         for limit_to_on_retrieve in [False, True]:
+            fields = self._fields[limit_to_on_retrieve] if limit_to_on_retrieve in self._fields else []
+            if limit_to_on_retrieve is True:
+                fields.extend(self._fields[False] if False in self._fields else [])
+            custom_fields = self._custom_fields[
+                limit_to_on_retrieve] if limit_to_on_retrieve in self._custom_fields else []
+            if limit_to_on_retrieve is True:
+                custom_fields.extend(self._custom_fields[False] if False in self._custom_fields else [])
+            relations = self._relations[limit_to_on_retrieve] if limit_to_on_retrieve in self._relations else []
+            if limit_to_on_retrieve is True:
+                relations.extend(self._relations[False] if False in self._relations else [])
+
             method_to_serializer[limit_to_on_retrieve] = \
                 _construct_serializer('Retrieve' if limit_to_on_retrieve else 'List', self._model, self._resource_name,
-                                      self._fields[
-                                          limit_to_on_retrieve] if limit_to_on_retrieve in self._fields else [],
-                                      self._custom_fields[
-                                          limit_to_on_retrieve] if limit_to_on_retrieve in self._custom_fields else [],
-                                      self._relations[
-                                          limit_to_on_retrieve] if limit_to_on_retrieve in self._relations else [],
+                                      fields,
+                                      custom_fields,
+                                      relations,
                                       self._related_limit,
                                       self._primary_key_name)
             _append_to_namespace(method_to_serializer[limit_to_on_retrieve])
